@@ -1,7 +1,5 @@
 """The |pydwf.core.api.analog_impedance| module implements a single class: |AnalogImpedance|."""
 
-from typing import Tuple
-
 from pydwf.core.dwf_device_subapi import AbstractDwfDeviceSubApi
 
 from pydwf.core.auxiliary.typespec_ctypes import typespec_ctypes
@@ -232,11 +230,11 @@ class AnalogImpedance(AbstractDwfDeviceSubApi):
         if result != RESULT_SUCCESS:
             raise self.dwf.exception()
 
-    def probeGet(self) -> Tuple[float, float]:
+    def probeGet(self) -> tuple[float, float]:
         """Get |AnalogImpedance| probe parameters.
 
         Returns:
-            Tuple[float, float]:
+            tuple[float, float]:
                 A two-element tuple: the probe resistance, in Ohms, and the probe capacity, in Farads.
 
         Raises:
@@ -292,7 +290,6 @@ class AnalogImpedance(AbstractDwfDeviceSubApi):
         Raises:
             DwfLibraryError: An error occurred while executing the operation.
         """
-
         result = self.lib.FDwfAnalogImpedanceCompReset(self.hdwf)
         if result != RESULT_SUCCESS:
             raise self.dwf.exception()
@@ -319,11 +316,11 @@ class AnalogImpedance(AbstractDwfDeviceSubApi):
         if result != RESULT_SUCCESS:
             raise self.dwf.exception()
 
-    def compGet(self) -> Tuple[float, float, float, float]:
+    def compGet(self) -> tuple[float, float, float, float]:
         """Get the |AnalogImpedance| measurement computation parameters.
 
         Returns:
-            Tuple[float, float, float, float]: The open-circuit resistance, open-circuit reactance,
+            tuple[float, float, float, float]: The open-circuit resistance, open-circuit reactance,
             short-circuit resistance, and short-circuit reactance (all in Ohms).
 
         Raises:
@@ -347,14 +344,14 @@ class AnalogImpedance(AbstractDwfDeviceSubApi):
         short_reactance = c_short_reactance.value
         return (open_resistance, open_reactance, short_resistance, short_reactance)
 
-    def statusInput(self, channel_index: int) -> Tuple[float, float]:
+    def statusInput(self, channel_index: int) -> tuple[float, float]:
         """Get the |AnalogImpedance| input measurement status.
 
         Parameters:
             channel_index(int): The channel for which to get gain and phase information.
 
         Returns:
-            Tuple[float, float]: The gain and phase (in radians) of the current measurement.
+            tuple[float, float]: The gain and phase (in radians) of the current measurement.
 
         Raises:
             DwfLibraryError: An error occurred while executing the operation.
@@ -372,6 +369,28 @@ class AnalogImpedance(AbstractDwfDeviceSubApi):
         radian = c_radian.value
         return (gain, radian)
 
+    def statusWarning(self, channel_index: int) -> int:
+        """Get warning for scope input range exceeded.
+
+        Parameters:
+            channel_index(int): The channel for which to get scope input range warning information.
+
+        Returns:
+            int: The warning, if any. 1 means *low*, 2 means *high*, 3 means *both*.
+
+        Raises:
+            DwfLibraryError: An error occurred while executing the operation.
+        """
+        c_warning = typespec_ctypes.c_int()
+        result = self.lib.FDwfAnalogImpedanceStatusWarning(
+            self.hdwf,
+            channel_index,
+            c_warning)
+        if result != RESULT_SUCCESS:
+            raise self.dwf.exception()
+        warning = c_warning.value
+        return warning
+
     def statusMeasure(self, measure: DwfAnalogImpedance) -> float:
         """Retrieve the |AnalogImpedance| measurement status value.
 
@@ -385,7 +404,7 @@ class AnalogImpedance(AbstractDwfDeviceSubApi):
             DwfLibraryError: An error occurred while executing the operation.
         """
         c_value = typespec_ctypes.c_double()
-        result = self.lib.FDwfAnalogImpedanceStatusInput(self.hdwf, measure.value, c_value)
+        result = self.lib.FDwfAnalogImpedanceStatusMeasure(self.hdwf, measure.value, c_value)
         if result != RESULT_SUCCESS:
             raise self.dwf.exception()
         value = c_value.value
