@@ -2,8 +2,6 @@
 
 # pylint: disable=too-many-lines
 
-from typing import Tuple, List
-
 import numpy as np
 
 from pydwf.core.dwf_device_subapi import AbstractDwfDeviceSubApi
@@ -12,7 +10,7 @@ from pydwf.core.auxiliary.typespec_ctypes import typespec_ctypes
 from pydwf.core.auxiliary.enum_types import (DwfAnalogInTriggerLengthCondition, DwfTriggerSource,
                                              DwfAnalogInTriggerType, DwfTriggerSlope, DwfAnalogInFilter,
                                              DwfAcquisitionMode, DwfState)
-from pydwf.core.auxiliary.constants  import RESULT_SUCCESS
+from pydwf.core.auxiliary.constants import RESULT_SUCCESS
 from pydwf.core.auxiliary.exceptions import PyDwfError
 
 
@@ -37,7 +35,7 @@ class AnalogIn(AbstractDwfDeviceSubApi):
     def reset(self) -> None:
         """Reset all |AnalogIn| instrument parameters to default values.
 
-        If auto-configuration is enabled at the device level, the reset operation is performed immediately;
+        If autoconfiguration is enabled at the device level, the reset operation is performed immediately;
         otherwise, an explicit call to the :py:meth:`configure` method is required.
 
         Raises:
@@ -112,11 +110,11 @@ class AnalogIn(AbstractDwfDeviceSubApi):
     #                                                                                                                  #
     ####################################################################################################################
 
-    def statusTime(self) -> Tuple[int, int, int]:
+    def statusTime(self) -> tuple[int, int, int]:
         """Retrieve the timestamp of the current status information.
 
         Returns:
-            Tuple[int, int, int]: A three-element tuple, indicating the POSIX timestamp of the status request.
+            tuple[int, int, int]: A three-element tuple, indicating the POSIX timestamp of the status request.
             The first element is the POSIX second, the second and third element are the numerator and denominator,
             respectively, of the fractional part of the second.
 
@@ -223,7 +221,7 @@ class AnalogIn(AbstractDwfDeviceSubApi):
             int: The buffer write index.
 
         Raises:
-            DwfLibraryError: An error occurred while retrieving the write index.
+            DwfLibraryError: An error occurred while retrieving the write-index.
         """
         c_index_write = typespec_ctypes.c_int()
         result = self.lib.FDwfAnalogInStatusIndexWrite(self.hdwf, c_index_write)
@@ -232,7 +230,7 @@ class AnalogIn(AbstractDwfDeviceSubApi):
         index_write = c_index_write.value
         return index_write
 
-    def statusRecord(self) -> Tuple[int, int, int]:
+    def statusRecord(self) -> tuple[int, int, int]:
         """Retrieve information about the recording process.
 
         Data loss occurs when the device acquisition is faster than the read process to the PC.
@@ -247,7 +245,7 @@ class AnalogIn(AbstractDwfDeviceSubApi):
         equal to buffer_size / sample_frequency).
 
         Returns:
-            Tuple[int, int, int]: A three-element tuple containing the counts for
+            tuple[int, int, int]: A three-element tuple containing the counts for
             *available*, *lost*, and *corrupt* data samples, in that order.
 
         Raises:
@@ -378,7 +376,7 @@ class AnalogIn(AbstractDwfDeviceSubApi):
             raise self.dwf.exception()
         return samples
 
-    def statusNoise(self, channel_index: int, count: int) -> Tuple[np.ndarray, np.ndarray]:
+    def statusNoise(self, channel_index: int, count: int) -> tuple[np.ndarray, np.ndarray]:
         """Retrieve the acquired noise samples from the specified |AnalogIn| instrument channel.
 
         Parameters:
@@ -405,7 +403,7 @@ class AnalogIn(AbstractDwfDeviceSubApi):
             raise self.dwf.exception()
         return (noise_min, noise_max)
 
-    def statusNoise2(self, channel_index: int, offset: int, count: int) -> Tuple[np.ndarray, np.ndarray]:
+    def statusNoise2(self, channel_index: int, offset: int, count: int) -> tuple[np.ndarray, np.ndarray]:
         """Retrieve the acquired data samples from the specified |AnalogIn| instrument channel.
 
         Parameters:
@@ -503,12 +501,12 @@ class AnalogIn(AbstractDwfDeviceSubApi):
         record_duration = c_record_duration.value
         return record_duration
 
-    def frequencyInfo(self) -> Tuple[float, float]:
+    def frequencyInfo(self) -> tuple[float, float]:
         """Retrieve the minimum and maximum configurable ADC sample frequency of the |AnalogIn| instrument,
         in samples/second.
 
         Returns:
-            Tuple[float, float]: The valid sample frequency range (min, max), in samples/second.
+            tuple[float, float]: The valid sample frequency range (min, max), in samples/second.
 
         Raises:
             DwfLibraryError: An error occurred while getting the allowed sample frequency range.
@@ -554,7 +552,7 @@ class AnalogIn(AbstractDwfDeviceSubApi):
         sample_frequency = c_sample_frequency.value
         return sample_frequency
 
-    def bufferSizeInfo(self) -> Tuple[int, int]:
+    def bufferSizeInfo(self) -> tuple[int, int]:
         """Returns the minimum and maximum allowable buffer size for the |AnalogIn| instrument, in samples.
 
         When using the :py:attr:`~pydwf.core.auxiliary.enum_types.DwfAcquisitionMode.Record` acquisition mode,
@@ -569,7 +567,7 @@ class AnalogIn(AbstractDwfDeviceSubApi):
             16384, depending on the device configuration.
 
         Returns:
-            Tuple[int, int]: A two-element tuple.
+            tuple[int, int]: A two-element tuple.
             The first element is the minimum buffer size, the second element is the maximum buffer size.
 
         Raises:
@@ -626,12 +624,12 @@ class AnalogIn(AbstractDwfDeviceSubApi):
         Raises:
             DwfLibraryError: An error occurred while getting the noise buffer size info.
         """
-        c_nSizeMax = typespec_ctypes.c_int()
-        result = self.lib.FDwfAnalogInNoiseSizeInfo(self.hdwf, c_nSizeMax)
+        c_noise_size = typespec_ctypes.c_int()
+        result = self.lib.FDwfAnalogInNoiseSizeInfo(self.hdwf, c_noise_size)
         if result != RESULT_SUCCESS:
             raise self.dwf.exception()
-        nSizeMax = c_nSizeMax.value
-        return nSizeMax
+        noise_size = c_noise_size.value
+        return noise_size
 
     def noiseSizeSet(self, noise_buffer_size: int) -> None:
         """Enable or disable the noise buffer for the |AnalogIn| instrument.
@@ -644,8 +642,8 @@ class AnalogIn(AbstractDwfDeviceSubApi):
 
             Any non-zero value enables the noise buffer; a zero value disables it.
 
-            If enabled, the noise buffer size as read by :py:meth:`noiseSizeGet` is always the size of the
-            sample buffer as read by :py:meth:`bufferSizeGet` divided by 8.
+            If enabled, the noise buffer size reported by :py:meth:`noiseSizeGet` is always equal to
+            the size of the sample buffer reported by :py:meth:`bufferSizeGet`, divided by 8.
 
         Parameters:
             noise_buffer_size (int): Whether to enable (non-zero) or disable (zero) the noise buffer.
@@ -677,11 +675,11 @@ class AnalogIn(AbstractDwfDeviceSubApi):
         noise_buffer_size = c_noise_buffer_size.value
         return noise_buffer_size
 
-    def acquisitionModeInfo(self) -> List[DwfAcquisitionMode]:
+    def acquisitionModeInfo(self) -> list[DwfAcquisitionMode]:
         """Get a list of valid |AnalogIn| instrument acquisition modes.
 
         Returns:
-            List[DwfAcquisitionMode]: A list of valid acquisition modes for the |AnalogIn| instrument.
+            list[DwfAcquisitionMode]: A list of valid acquisition modes for the |AnalogIn| instrument.
 
         Raises:
             DwfLibraryError: An error occurred while getting the acquisition mode info.
@@ -786,11 +784,11 @@ class AnalogIn(AbstractDwfDeviceSubApi):
         channel_enable = bool(c_channel_enable.value)
         return channel_enable
 
-    def channelFilterInfo(self) -> List[DwfAnalogInFilter]:
+    def channelFilterInfo(self) -> list[DwfAnalogInFilter]:
         """Get a list of valid |AnalogIn| channel filter settings.
 
         Returns:
-            List[DwfAnalogInFilter]: A list of valid channel filter settings.
+            list[DwfAnalogInFilter]: A list of valid channel filter settings.
 
         Raises:
             DwfLibraryError: An error occurred while getting the channel filter info.
@@ -837,7 +835,7 @@ class AnalogIn(AbstractDwfDeviceSubApi):
         channel_filter = DwfAnalogInFilter(c_channel_filter.value)
         return channel_filter
 
-    def channelRangeInfo(self) -> Tuple[float, float, int]:
+    def channelRangeInfo(self) -> tuple[float, float, int]:
         """Report the possible voltage range of the |AnalogIn| input channels, in Volts.
 
         The values returned represent ideal values.
@@ -848,7 +846,7 @@ class AnalogIn(AbstractDwfDeviceSubApi):
             in a different representation.
 
         Returns:
-            Tuple[float, float, int]: The minimum range (Volts), maximum range (Volts),
+            tuple[float, float, int]: The minimum range (Volts), maximum range (Volts),
             and number of different discrete channel range settings of the |AnalogIn| instrument.
 
         Raises:
@@ -913,7 +911,7 @@ class AnalogIn(AbstractDwfDeviceSubApi):
         channel_range = c_channel_range.value
         return channel_range
 
-    def channelRangeSteps(self) -> List[float]:
+    def channelRangeSteps(self) -> list[float]:
         """Report the possible voltage ranges of the |AnalogIn| input channels, in Volts, as a list.
 
         The values returned represent ideal values.
@@ -924,7 +922,7 @@ class AnalogIn(AbstractDwfDeviceSubApi):
             in a different representation.
 
         Returns:
-            List[float]: A list of ranges, in Volts, representing the discrete
+            list[float]: A list of ranges, in Volts, representing the discrete
             channel range settings of the |AnalogIn| instrument.
 
         Raises:
@@ -939,11 +937,11 @@ class AnalogIn(AbstractDwfDeviceSubApi):
         channel_range_array = [c_channel_range_array[index] for index in range(channel_range_array_size)]
         return channel_range_array
 
-    def channelOffsetInfo(self) -> Tuple[float, float, int]:
+    def channelOffsetInfo(self) -> tuple[float, float, int]:
         """Get the possible |AnalogIn| input channel offset settings, in Volts.
 
         Returns:
-            Tuple[float, float, int]: The minimum channel offset (Volts), maximum channel offset (Volts),
+            tuple[float, float, int]: The minimum channel offset (Volts), maximum channel offset (Volts),
             and number of steps.
 
         Raises:
@@ -1148,7 +1146,7 @@ class AnalogIn(AbstractDwfDeviceSubApi):
     #                                                                                                                  #
     ####################################################################################################################
 
-    def triggerSourceInfo(self) -> List[DwfTriggerSource]:
+    def triggerSourceInfo(self) -> list[DwfTriggerSource]:
         """Get the |AnalogIn| instrument trigger source info.
 
         Warning:
@@ -1157,7 +1155,7 @@ class AnalogIn(AbstractDwfDeviceSubApi):
             Use the generic |DwfDevice.triggerInfo:link| method instead.
 
         Returns:
-            List[DwfTriggerSource]: A list of trigger sources that can be selected.
+            list[DwfTriggerSource]: A list of trigger sources that can be selected.
 
         Raises:
             DwfLibraryError: An error occurred while retrieving the trigger source information.
@@ -1200,11 +1198,11 @@ class AnalogIn(AbstractDwfDeviceSubApi):
         trigger_source = DwfTriggerSource(c_trigger_source.value)
         return trigger_source
 
-    def triggerPositionInfo(self) -> Tuple[float, float, int]:
+    def triggerPositionInfo(self) -> tuple[float, float, int]:
         """Get the |AnalogIn| instrument trigger position range.
 
         Returns:
-            Tuple[float, float, int]: The valid range of trigger positions that can be configured.
+            tuple[float, float, int]: The valid range of trigger positions that can be configured.
             The values returned are the *minimum* and *maximum* valid position settings, and the number of steps.
 
         Raises:
@@ -1289,11 +1287,11 @@ class AnalogIn(AbstractDwfDeviceSubApi):
         trigger_position = c_trigger_position.value
         return trigger_position
 
-    def triggerAutoTimeoutInfo(self) -> Tuple[float, float, int]:
+    def triggerAutoTimeoutInfo(self) -> tuple[float, float, int]:
         """Get the |AnalogIn| instrument trigger auto-timeout range, in seconds.
 
         Returns:
-            Tuple[float, float, int]: The valid range of trigger auto-timeout values that can be configured.
+            tuple[float, float, int]: The valid range of trigger auto-timeout values that can be configured.
             The values returned are the *minimum* and *maximum* valid auto-timeout settings, and the number of steps.
 
         Raises:
@@ -1377,14 +1375,14 @@ class AnalogIn(AbstractDwfDeviceSubApi):
     #                                                                                                                  #
     ####################################################################################################################
 
-    def triggerHoldOffInfo(self) -> Tuple[float, float, int]:
+    def triggerHoldOffInfo(self) -> tuple[float, float, int]:
         """Get the |AnalogIn| trigger detector holdoff range, in seconds.
 
         The trigger holdoff setting is the minimum time (in seconds) that should pass for a trigger to be
         recognized by the trigger detector after a previous trigger event.
 
         Returns:
-            Tuple[float, float, int]: The valid range of trigger detector holdoff values that can be configured.
+            tuple[float, float, int]: The valid range of trigger detector holdoff values that can be configured.
             The values returned are the *minimum* and *maximum* valid holdoff settings, and the number of steps.
 
         Raises:
@@ -1442,14 +1440,14 @@ class AnalogIn(AbstractDwfDeviceSubApi):
         trigger_detector_holdoff = c_trigger_detector_holdoff.value
         return trigger_detector_holdoff
 
-    def triggerTypeInfo(self) -> List[DwfAnalogInTriggerType]:
+    def triggerTypeInfo(self) -> list[DwfAnalogInTriggerType]:
         """Get the valid |AnalogIn| trigger detector trigger-type values.
 
         This setting determines the type of event recognized by the |AnalogIn| trigger detector as a trigger.
         Possible types includes *Edge*, *Pulse*, *Transition*, and *Window*.
 
         Returns:
-            List[DwfAnalogInTriggerType]: A list of trigger detector trigger-types that can be configured.
+            list[DwfAnalogInTriggerType]: A list of trigger detector trigger-types that can be configured.
 
         Raises:
             DwfLibraryError: An error occurred while getting the trigger detector trigger-type info.
@@ -1459,8 +1457,10 @@ class AnalogIn(AbstractDwfDeviceSubApi):
         if result != RESULT_SUCCESS:
             raise self.dwf.exception()
         trigger_detector_type_bitset = c_trigger_detector_type_bitset.value
-        trigger_detector_type_list = [trigger_detector_type for trigger_detector_type in DwfAnalogInTriggerType
-                             if trigger_detector_type_bitset & (1 << trigger_detector_type.value)]
+        trigger_detector_type_list = [
+            trigger_detector_type for trigger_detector_type in DwfAnalogInTriggerType
+            if trigger_detector_type_bitset & (1 << trigger_detector_type.value)
+        ]
         return trigger_detector_type_list
 
     def triggerTypeSet(self, trigger_detector_type: DwfAnalogInTriggerType) -> None:
@@ -1492,7 +1492,7 @@ class AnalogIn(AbstractDwfDeviceSubApi):
         trigger_detector_type = DwfAnalogInTriggerType(c_trigger_detector_type.value)
         return trigger_detector_type
 
-    def triggerChannelInfo(self) -> Tuple[int, int]:
+    def triggerChannelInfo(self) -> tuple[int, int]:
         """Get the |AnalogIn| trigger detector channel range.
 
         The |AnalogIn| trigger detector monitors a specific analog in channel for trigger events.
@@ -1500,7 +1500,7 @@ class AnalogIn(AbstractDwfDeviceSubApi):
         as the |AnalogIn| trigger detector channel.
 
         Returns:
-            Tuple[int, int]: The first and last channel that can be used as trigger detector channels.
+            tuple[int, int]: The first and last channel that can be used as trigger detector channels.
 
         Raises:
             DwfLibraryError: An error occurred while getting the trigger detector channel range.
@@ -1550,11 +1550,11 @@ class AnalogIn(AbstractDwfDeviceSubApi):
         trigger_detector_channel_index = c_trigger_detector_channel_index.value
         return trigger_detector_channel_index
 
-    def triggerFilterInfo(self) -> List[DwfAnalogInFilter]:
+    def triggerFilterInfo(self) -> list[DwfAnalogInFilter]:
         """Get a list of valid |AnalogIn| trigger detector filter values.
 
         Returns:
-            List[DwfAnalogInFilter]: A list of filters that can be configured for the trigger detector channel.
+            list[DwfAnalogInFilter]: A list of filters that can be configured for the trigger detector channel.
 
         Raises:
             DwfLibraryError: An error occurred while getting the valid trigger detector channel filter values.
@@ -1564,8 +1564,10 @@ class AnalogIn(AbstractDwfDeviceSubApi):
         if result != RESULT_SUCCESS:
             raise self.dwf.exception()
         trigger_detector_filter_bitset = c_trigger_detector_filter_bitset.value
-        trigger_detector_filter_list = [trigger_detector_filter for trigger_detector_filter in DwfAnalogInFilter
-                               if trigger_detector_filter_bitset & (1 << trigger_detector_filter.value)]
+        trigger_detector_filter_list = [
+            trigger_detector_filter for trigger_detector_filter in DwfAnalogInFilter
+            if trigger_detector_filter_bitset & (1 << trigger_detector_filter.value)
+        ]
         return trigger_detector_filter_list
 
     def triggerFilterSet(self, trigger_detector_filter: DwfAnalogInFilter) -> None:
@@ -1597,11 +1599,11 @@ class AnalogIn(AbstractDwfDeviceSubApi):
         trigger_detector_filter = DwfAnalogInFilter(c_trigger_detector_filter.value)
         return trigger_detector_filter
 
-    def triggerLevelInfo(self) -> Tuple[float, float, int]:
+    def triggerLevelInfo(self) -> tuple[float, float, int]:
         """Get the |AnalogIn| trigger detector valid trigger level range, in Volts.
 
         Returns:
-            Tuple[float, float, int]: The range of valid trigger levels that can be configured.
+            tuple[float, float, int]: The range of valid trigger levels that can be configured.
             The values returned are the *minimum* and *maximum* trigger levels in Volts, and the number of steps.
 
         Raises:
@@ -1632,7 +1634,7 @@ class AnalogIn(AbstractDwfDeviceSubApi):
         """Set the |AnalogIn| trigger detector trigger-level, in Volts.
 
         Parameters:
-            trigger_level (float): The trigger level to be configured, in Volts.
+            trigger_detector_level (float): The trigger level to be configured, in Volts.
 
         Raises:
             DwfLibraryError: An error occurred while setting the trigger level.
@@ -1657,11 +1659,11 @@ class AnalogIn(AbstractDwfDeviceSubApi):
         trigger_detector_level = c_trigger_detector_level.value
         return trigger_detector_level
 
-    def triggerHysteresisInfo(self) -> Tuple[float, float, int]:
+    def triggerHysteresisInfo(self) -> tuple[float, float, int]:
         """Get the |AnalogIn| trigger detector valid hysteresis range, in Volts.
 
         Returns:
-            Tuple[float, float, int]: The valid range of trigger hysteresis values that can be configured.
+            tuple[float, float, int]: The valid range of trigger hysteresis values that can be configured.
             The values returned are the *minimum* and *maximum* trigger hysteresis levels in Volts,
             and the number of steps.
 
@@ -1718,11 +1720,11 @@ class AnalogIn(AbstractDwfDeviceSubApi):
         trigger_detector_hysteresis = c_trigger_detector_hysteresis.value
         return trigger_detector_hysteresis
 
-    def triggerConditionInfo(self) -> List[DwfTriggerSlope]:
+    def triggerConditionInfo(self) -> list[DwfTriggerSlope]:
         """Get the valid |AnalogIn| trigger detector condition (slope) options.
 
         Returns:
-            List[DwfTriggerSlope]: A list of valid trigger detector condition (slope) values.
+            list[DwfTriggerSlope]: A list of valid trigger detector condition (slope) values.
 
         Raises:
             DwfLibraryError: An error occurred while getting the valid trigger detector condition values.
@@ -1734,8 +1736,10 @@ class AnalogIn(AbstractDwfDeviceSubApi):
         if result != RESULT_SUCCESS:
             raise self.dwf.exception()
         trigger_detector_condition_bitset = c_trigger_detector_condition_bitset.value
-        trigger_detector_condition_list = [trigger_detector_condition for trigger_detector_condition in DwfTriggerSlope
-                                  if trigger_detector_condition_bitset & (1 << trigger_detector_condition.value)]
+        trigger_detector_condition_list = [
+            trigger_detector_condition for trigger_detector_condition in DwfTriggerSlope
+            if trigger_detector_condition_bitset & (1 << trigger_detector_condition.value)
+        ]
         return trigger_detector_condition_list
 
     def triggerConditionSet(self, trigger_detector_condition: DwfTriggerSlope) -> None:
@@ -1767,11 +1771,11 @@ class AnalogIn(AbstractDwfDeviceSubApi):
         trigger_detector_condition = DwfTriggerSlope(c_trigger_detector_condition.value)
         return trigger_detector_condition
 
-    def triggerLengthInfo(self) -> Tuple[float, float, int]:
+    def triggerLengthInfo(self) -> tuple[float, float, int]:
         """Get the valid |AnalogIn| trigger detector length range, in seconds.
 
         Returns:
-            Tuple[float, float, int]: The valid range of trigger detector length values that can be configured.
+            tuple[float, float, int]: The valid range of trigger detector length values that can be configured.
             The values returned are the *minimum* and *maximum* trigger detector length values in seconds,
             and the number of steps.
 
@@ -1828,13 +1832,13 @@ class AnalogIn(AbstractDwfDeviceSubApi):
         trigger_length = c_trigger_length.value
         return trigger_length
 
-    def triggerLengthConditionInfo(self) -> List[DwfAnalogInTriggerLengthCondition]:
+    def triggerLengthConditionInfo(self) -> list[DwfAnalogInTriggerLengthCondition]:
         """Get a list of valid |AnalogIn| trigger detector length condition values.
 
         Trigger length condition values include *Less*, *Timeout*, and *More*.
 
         Returns:
-            List[DwfAnalogInTriggerLengthCondition]: A list of valid trigger detector length condition values.
+            list[DwfAnalogInTriggerLengthCondition]: A list of valid trigger detector length condition values.
 
         Raises:
             DwfLibraryError: An error occurred while getting the trigger length condition info.
