@@ -2,8 +2,6 @@
 
 # pylint: disable=too-many-lines
 
-from typing import Tuple, List
-
 import numpy as np
 
 from pydwf.core.dwf_device_subapi import AbstractDwfDeviceSubApi
@@ -109,14 +107,14 @@ class AnalogOut(AbstractDwfDeviceSubApi):
     #                                                                                                                  #
     ####################################################################################################################
 
-    def waitInfo(self, channel_index: int) -> Tuple[float, float]:
+    def waitInfo(self, channel_index: int) -> tuple[float, float]:
         """Get the |AnalogOut| channel valid |Wait:link| state duration range, in seconds.
 
         Parameters:
             channel_index (int): The |AnalogOut| channel.
 
         Returns:
-            Tuple[float, float]: The range of configurable |Wait:link| state durations, in seconds.
+            tuple[float, float]: The range of configurable |Wait:link| state durations, in seconds.
 
         Raises:
             DwfLibraryError: An error occurred while executing the operation.
@@ -163,14 +161,14 @@ class AnalogOut(AbstractDwfDeviceSubApi):
         wait_duration = c_wait_duration.value
         return wait_duration
 
-    def runInfo(self, channel_index: int) -> Tuple[float, float]:
+    def runInfo(self, channel_index: int) -> tuple[float, float]:
         """Get the |AnalogOut| channel valid |Running:link| state duration range, in seconds.
 
         Parameters:
             channel_index (int): The |AnalogOut| channel.
 
         Returns:
-            Tuple[float, float]: The range of allowed |Running:link| state durations, in seconds.
+            tuple[float, float]: The range of allowed |Running:link| state durations, in seconds.
 
         Raises:
             DwfLibraryError: An error occurred while executing the operation.
@@ -276,7 +274,7 @@ class AnalogOut(AbstractDwfDeviceSubApi):
         repeat_trigger_flag = bool(c_repeat_trigger_flag.value)
         return repeat_trigger_flag
 
-    def repeatInfo(self, channel_index: int) -> Tuple[int, int]:
+    def repeatInfo(self, channel_index: int) -> tuple[int, int]:
         """Get |AnalogOut| repeat count range.
 
         The *repeat count* is the number of times the |AnalogOut| channel will go through the
@@ -286,7 +284,7 @@ class AnalogOut(AbstractDwfDeviceSubApi):
             channel_index (int): The |AnalogOut| channel.
 
         Returns:
-            Tuple[int, int]: The range of configurable repeat values.
+            tuple[int, int]: The range of configurable repeat values.
 
         Raises:
             DwfLibraryError: An error occurred while executing the operation.
@@ -401,7 +399,7 @@ class AnalogOut(AbstractDwfDeviceSubApi):
     #                                                                                                                  #
     ####################################################################################################################
 
-    def triggerSourceInfo(self) -> List[DwfTriggerSource]:
+    def triggerSourceInfo(self) -> list[DwfTriggerSource]:
         """Get a list of valid |AnalogOut| instrument trigger sources.
 
         Warning:
@@ -410,7 +408,7 @@ class AnalogOut(AbstractDwfDeviceSubApi):
             Use the generic |DwfDevice.triggerInfo:link| method instead.
 
         Returns:
-            List[DwfTriggerSource]: The list of DwfTriggerSource values that can be configured.
+            list[DwfTriggerSource]: The list of DwfTriggerSource values that can be configured.
 
         Raises:
             DwfLibraryError: An error occurred while executing the operation.
@@ -535,14 +533,14 @@ class AnalogOut(AbstractDwfDeviceSubApi):
         mode = DwfAnalogOutMode(c_mode.value)
         return mode
 
-    def idleInfo(self, channel_index: int) -> List[DwfAnalogOutIdle]:
+    def idleInfo(self, channel_index: int) -> list[DwfAnalogOutIdle]:
         """Get the valid |AnalogOut| channel idle settings.
 
         Parameters:
             channel_index (int): The |AnalogOut| channel.
 
         Returns:
-            List[DwfAnalogOutIdle]: A list of options for the channel behavior when idle.
+            list[DwfAnalogOutIdle]: A list of options for the channel behavior when idle.
 
         Raises:
             DwfLibraryError: An error occurred while executing the operation.
@@ -588,14 +586,14 @@ class AnalogOut(AbstractDwfDeviceSubApi):
         idle = DwfAnalogOutIdle(c_idle.value)
         return idle
 
-    def limitationInfo(self, channel_index: int) -> Tuple[float, float]:
+    def limitationInfo(self, channel_index: int) -> tuple[float, float]:
         """Get the |AnalogOut| channel limitation range, in Volts or Amps.
 
         Parameters:
             channel_index (int): The |AnalogOut| channel.
 
         Returns:
-            Tuple[float, float]: The range of limitation values that can be configured.
+            tuple[float, float]: The range of limitation values that can be configured.
 
         Raises:
             DwfLibraryError: An error occurred while executing the operation.
@@ -707,14 +705,14 @@ class AnalogOut(AbstractDwfDeviceSubApi):
     #                                                                                                                  #
     ####################################################################################################################
 
-    def nodeInfo(self, channel_index: int) -> List[DwfAnalogOutNode]:
+    def nodeInfo(self, channel_index: int) -> list[DwfAnalogOutNode]:
         """Get a list of valid |AnalogOut| channel nodes.
 
         Parameters:
             channel_index (int): The |AnalogOut| channel.
 
         Returns:
-            List[DwfAnalogOutNode]: The valid nodes for this channel.
+            list[DwfAnalogOutNode]: The valid nodes for this channel.
 
         Raises:
             DwfLibraryError: An error occurred while executing the operation.
@@ -768,7 +766,7 @@ class AnalogOut(AbstractDwfDeviceSubApi):
         enable = bool(c_enable.value)
         return enable
 
-    def nodeFunctionInfo(self, channel_index: int, node: DwfAnalogOutNode) -> List[DwfAnalogOutFunction]:
+    def nodeFunctionInfo(self, channel_index: int, node: DwfAnalogOutNode) -> list[DwfAnalogOutFunction]:
         """Get the valid waveform shape function options of an |AnalogOut| channel node.
 
         Parameters:
@@ -776,7 +774,7 @@ class AnalogOut(AbstractDwfDeviceSubApi):
             node (DwfAnalogOutNode): The channel node.
 
         Returns:
-            List[DwfAnalogOutFunction]: The available node waveform shape functions.
+            list[DwfAnalogOutFunction]: The available node waveform shape functions.
 
         Raises:
             DwfLibraryError: An error occurred while executing the operation.
@@ -828,7 +826,7 @@ class AnalogOut(AbstractDwfDeviceSubApi):
         func = DwfAnalogOutFunction(c_func.value)
         return func
 
-    def nodeFrequencyInfo(self, channel_index: int, node: DwfAnalogOutNode) -> Tuple[float, float]:
+    def nodeFrequencyInfo(self, channel_index: int, node: DwfAnalogOutNode) -> tuple[float, float]:
         """Get the channel node valid frequency range for an |AnalogOut| channel node, in Hz.
 
         Parameters:
@@ -836,7 +834,7 @@ class AnalogOut(AbstractDwfDeviceSubApi):
             node (DwfAnalogOutNode): The channel node.
 
         Returns:
-            Tuple[float, float]: The range of valid frequencies, in Hz.
+            tuple[float, float]: The range of valid frequencies, in Hz.
 
         Raises:
             DwfLibraryError: An error occurred while executing the operation.
@@ -898,7 +896,7 @@ class AnalogOut(AbstractDwfDeviceSubApi):
         frequency = c_frequency.value
         return frequency
 
-    def nodeAmplitudeInfo(self, channel_index: int, node: DwfAnalogOutNode) -> Tuple[float, float]:
+    def nodeAmplitudeInfo(self, channel_index: int, node: DwfAnalogOutNode) -> tuple[float, float]:
         """Get the amplitude range for an |AnalogOut| channel node, in Volts.
 
         Parameters:
@@ -906,7 +904,7 @@ class AnalogOut(AbstractDwfDeviceSubApi):
             node (DwfAnalogOutNode): The channel node.
 
         Returns:
-            Tuple[float, float]: The range of allowed amplitude values, in Volts.
+            tuple[float, float]: The range of allowed amplitude values, in Volts.
 
         Raises:
             DwfLibraryError: An error occurred while executing the operation.
@@ -968,7 +966,7 @@ class AnalogOut(AbstractDwfDeviceSubApi):
         amplitude = c_amplitude.value
         return amplitude
 
-    def nodeOffsetInfo(self, channel_index: int, node: DwfAnalogOutNode) -> Tuple[float, float]:
+    def nodeOffsetInfo(self, channel_index: int, node: DwfAnalogOutNode) -> tuple[float, float]:
         """Get the valid offset range for an |AnalogOut| channel node, in Volts.
 
         Parameters:
@@ -1028,7 +1026,7 @@ class AnalogOut(AbstractDwfDeviceSubApi):
         offset = c_offset.value
         return offset
 
-    def nodeSymmetryInfo(self, channel_index: int, node: DwfAnalogOutNode) -> Tuple[float, float]:
+    def nodeSymmetryInfo(self, channel_index: int, node: DwfAnalogOutNode) -> tuple[float, float]:
         """Get the *symmetry* range for an |AnalogOut| channel node.
 
         The *symmetry* value alters the waveform shape function of the node.
@@ -1042,7 +1040,7 @@ class AnalogOut(AbstractDwfDeviceSubApi):
             node (DwfAnalogOutNode): The channel node.
 
         Returns:
-            Tuple[float, float]: The range of valid symmetry settings.
+            tuple[float, float]: The range of valid symmetry settings.
 
         Raises:
             DwfLibraryError: An error occurred while executing the operation.
@@ -1108,7 +1106,7 @@ class AnalogOut(AbstractDwfDeviceSubApi):
         symmetry = c_symmetry.value
         return symmetry
 
-    def nodePhaseInfo(self, channel_index: int, node: DwfAnalogOutNode) -> Tuple[float, float]:
+    def nodePhaseInfo(self, channel_index: int, node: DwfAnalogOutNode) -> tuple[float, float]:
         """Get the valid phase range for an |AnalogOut| channel node, in degrees.
 
         Parameters:
@@ -1116,7 +1114,7 @@ class AnalogOut(AbstractDwfDeviceSubApi):
             node (DwfAnalogOutNode): The channel node.
 
         Returns:
-            Tuple[float, float]: The range of valid channel node phase values, in degrees.
+            tuple[float, float]: The range of valid channel node phase values, in degrees.
 
         Raises:
             DwfLibraryError: An error occurred while executing the operation.
@@ -1184,7 +1182,7 @@ class AnalogOut(AbstractDwfDeviceSubApi):
     #                                                                                                                  #
     ####################################################################################################################
 
-    def nodeDataInfo(self, channel_index: int, node: DwfAnalogOutNode) -> Tuple[float, float]:
+    def nodeDataInfo(self, channel_index: int, node: DwfAnalogOutNode) -> tuple[float, float]:
         """Get data range for an |AnalogOut| channel node, in samples.
 
         Parameters:
@@ -1192,7 +1190,7 @@ class AnalogOut(AbstractDwfDeviceSubApi):
             node (DwfAnalogOutNode): The channel node.
 
         Returns:
-            Tuple[float, float]: The range of valid values.
+            tuple[float, float]: The range of valid values.
 
         Raises:
             DwfLibraryError: An error occurred while executing the operation.
@@ -1234,7 +1232,7 @@ class AnalogOut(AbstractDwfDeviceSubApi):
         if result != RESULT_SUCCESS:
             raise self.dwf.exception()
 
-    def nodePlayStatus(self, channel_index: int, node: DwfAnalogOutNode) -> Tuple[int, int, int]:
+    def nodePlayStatus(self, channel_index: int, node: DwfAnalogOutNode) -> tuple[int, int, int]:
         """Get the play status for an |AnalogOut| channel node.
 
         Parameters:
@@ -1242,7 +1240,7 @@ class AnalogOut(AbstractDwfDeviceSubApi):
             node (DwfAnalogOutNode): The channel node.
 
         Returns:
-            Tuple[int, int, int]: The *free*, *lost*, and *corrupted* status counts, in samples.
+            tuple[int, int, int]: The *free*, *lost*, and *corrupted* status counts, in samples.
 
         Raises:
             DwfLibraryError: An error occurred while executing the operation.
@@ -1333,7 +1331,7 @@ class AnalogOut(AbstractDwfDeviceSubApi):
         enable = bool(c_enable.value)
         return enable
 
-    def functionInfo(self, channel_index: int) -> List[DwfAnalogOutFunction]:
+    def functionInfo(self, channel_index: int) -> list[DwfAnalogOutFunction]:
         """Get the |AnalogOut| channel waveform shape function info.
 
         Warning:
@@ -1342,7 +1340,7 @@ class AnalogOut(AbstractDwfDeviceSubApi):
             Use the :py:meth:`nodeFunctionInfo` method instead.
 
         Returns:
-            List[DwfAnalogOutFunction]: The valid waveform shape functions.
+            list[DwfAnalogOutFunction]: The valid waveform shape functions.
 
         Parameters:
             channel_index (int): The |AnalogOut| channel.
@@ -1402,7 +1400,7 @@ class AnalogOut(AbstractDwfDeviceSubApi):
         func = DwfAnalogOutFunction(c_func.value)
         return func
 
-    def frequencyInfo(self, channel_index: int) -> Tuple[float, float]:
+    def frequencyInfo(self, channel_index: int) -> tuple[float, float]:
         """Get the |AnalogOut| channel valid frequency range, in Hz.
 
         Warning:
@@ -1414,19 +1412,19 @@ class AnalogOut(AbstractDwfDeviceSubApi):
             channel_index (int): The |AnalogOut| channel.
 
         Returns:
-            Tuple[float, float]: The valid frequency range, in Hz.
+            tuple[float, float]: The valid frequency range, in Hz.
 
         Raises:
             DwfLibraryError: An error occurred while executing the operation.
         """
-        c_hzMin = typespec_ctypes.c_double()
-        c_hzMax = typespec_ctypes.c_double()
-        result = self.lib.FDwfAnalogOutFrequencyInfo(self.hdwf, channel_index, c_hzMin, c_hzMax)
+        c_frequency_min = typespec_ctypes.c_double()
+        c_frequency_max = typespec_ctypes.c_double()
+        result = self.lib.FDwfAnalogOutFrequencyInfo(self.hdwf, channel_index, c_frequency_min, c_frequency_max)
         if result != RESULT_SUCCESS:
             raise self.dwf.exception()
-        hzMin = c_hzMin.value
-        hzMax = c_hzMax.value
-        return (hzMin, hzMax)
+        frequency_min = c_frequency_min.value
+        frequency_max = c_frequency_max.value
+        return (frequency_min, frequency_max)
 
     def frequencySet(self, channel_index: int, frequency: float) -> None:
         """Set the |AnalogOut| channel frequency, in Hz.
@@ -1464,14 +1462,14 @@ class AnalogOut(AbstractDwfDeviceSubApi):
         Raises:
             DwfLibraryError: An error occurred while executing the operation.
         """
-        c_hzFrequency = typespec_ctypes.c_double()
-        result = self.lib.FDwfAnalogOutFrequencyGet(self.hdwf, channel_index, c_hzFrequency)
+        c_frequency = typespec_ctypes.c_double()
+        result = self.lib.FDwfAnalogOutFrequencyGet(self.hdwf, channel_index, c_frequency)
         if result != RESULT_SUCCESS:
             raise self.dwf.exception()
-        hzFrequency = c_hzFrequency.value
-        return hzFrequency
+        frequency = c_frequency.value
+        return frequency
 
-    def amplitudeInfo(self, channel_index: int) -> Tuple[float, float]:
+    def amplitudeInfo(self, channel_index: int) -> tuple[float, float]:
         """Get the |AnalogOut| channel amplitude range info.
 
         Warning:
@@ -1540,7 +1538,7 @@ class AnalogOut(AbstractDwfDeviceSubApi):
         amplitude = c_amplitude.value
         return amplitude
 
-    def offsetInfo(self, channel_index: int) -> Tuple[float, float]:
+    def offsetInfo(self, channel_index: int) -> tuple[float, float]:
         """Get the |AnalogOut| channel offset range info, in Volts.
 
         Warning:
@@ -1552,7 +1550,7 @@ class AnalogOut(AbstractDwfDeviceSubApi):
             channel_index (int): The |AnalogOut| channel.
 
         Returns:
-            Tuple[float, float]: The valid range of offset values, in Volts.
+            tuple[float, float]: The valid range of offset values, in Volts.
 
         Raises:
             DwfLibraryError: An error occurred while executing the operation.
@@ -1609,7 +1607,7 @@ class AnalogOut(AbstractDwfDeviceSubApi):
         offset = c_offset.value
         return offset
 
-    def symmetryInfo(self, channel_index: int) -> Tuple[float, float]:
+    def symmetryInfo(self, channel_index: int) -> tuple[float, float]:
         """Get the |AnalogOut| channel symmetry setting range.
 
         Warning:
@@ -1621,7 +1619,7 @@ class AnalogOut(AbstractDwfDeviceSubApi):
             channel_index (int): The |AnalogOut| channel.
 
         Returns:
-            Tuple[float, float]: The range of valid symmetry settings.
+            tuple[float, float]: The range of valid symmetry settings.
 
         Raises:
             DwfLibraryError: An error occurred while executing the operation.
@@ -1678,7 +1676,7 @@ class AnalogOut(AbstractDwfDeviceSubApi):
         symmetry = c_symmetry.value
         return symmetry
 
-    def phaseInfo(self, channel_index: int) -> Tuple[float, float]:
+    def phaseInfo(self, channel_index: int) -> tuple[float, float]:
         """Get the |AnalogOut| channel phase range, in degrees.
 
         Warning:
@@ -1690,7 +1688,7 @@ class AnalogOut(AbstractDwfDeviceSubApi):
             channel_index (int): The |AnalogOut| channel.
 
         Returns:
-            Tuple[float, float]: The range of valid phase values, in degrees.
+            tuple[float, float]: The range of valid phase values, in degrees.
 
         Raises:
             DwfLibraryError: An error occurred while executing the operation.
@@ -1753,7 +1751,7 @@ class AnalogOut(AbstractDwfDeviceSubApi):
     #                                                                                                                  #
     ####################################################################################################################
 
-    def dataInfo(self, channel_index: int) -> Tuple[int, int]:
+    def dataInfo(self, channel_index: int) -> tuple[int, int]:
         """Get the |AnalogOut| channel data buffer range.
 
         Warning:
@@ -1765,7 +1763,7 @@ class AnalogOut(AbstractDwfDeviceSubApi):
             channel_index (int): The |AnalogOut| channel.
 
         Returns:
-            Tuple[int, int]: The data range.
+            tuple[int, int]: The data range.
 
         Raises:
             DwfLibraryError: An error occurred while executing the operation.
@@ -1805,7 +1803,7 @@ class AnalogOut(AbstractDwfDeviceSubApi):
         if result != RESULT_SUCCESS:
             raise self.dwf.exception()
 
-    def playStatus(self, channel_index: int) -> Tuple[int, int, int]:
+    def playStatus(self, channel_index: int) -> tuple[int, int, int]:
         """Get the |AnalogOut| channel playback status, in samples.
 
         Warning:
@@ -1817,7 +1815,7 @@ class AnalogOut(AbstractDwfDeviceSubApi):
             channel_index (int): The |AnalogOut| channel.
 
         Returns:
-            Tuple[int, int, int]: The playback status.
+            tuple[int, int, int]: The playback status.
 
         Raises:
             DwfLibraryError: An error occurred while executing the operation.
