@@ -1,7 +1,7 @@
 """The |pydwf.core.api.device_enumeration| module implements a single class: |Enum|."""
 
 import ctypes
-from typing import Optional, Tuple, Union
+from typing import Optional, Union
 
 from pydwf.core.dwf_library_subapi import AbstractDwfLibrarySubApi
 
@@ -144,8 +144,7 @@ class DeviceEnumeration(AbstractDwfLibrarySubApi):
         if result != RESULT_SUCCESS:
             raise self.dwf.exception()
 
-
-    def deviceType(self, device_index: int) -> Tuple[int, int]:
+    def deviceType(self, device_index: int) -> tuple[int, int]:
         """Return the device ID and version (hardware revision) of the selected Digilent Waveforms device.
 
         Note:
@@ -159,7 +158,7 @@ class DeviceEnumeration(AbstractDwfLibrarySubApi):
                 (see the :py:meth:`enumerateDevices` method).
 
         Returns:
-            Tuple[int, int]: A tuple of the |DwfDeviceID:link| and |DwfDeviceVersion:link| integer
+            tuple[int, int]: A tuple of the |DwfDeviceID:link| and |DwfDeviceVersion:link| integer
             values of the selected Digilent Waveforms device.
 
         Raises:
@@ -197,18 +196,18 @@ class DeviceEnumeration(AbstractDwfLibrarySubApi):
         return is_used
 
     def userName(self, device_index: int) -> str:
-        """Retrieve the user name of the selected Digilent Waveforms device.
+        """Retrieve the username of the selected Digilent Waveforms device.
 
         Parameters:
             device_index (int): Zero-based index of the previously enumerated Digilent Waveforms device
                 (see the :py:meth:`enumerateDevices` method).
 
         Returns:
-            str: The user name of the Digilent Waveforms device, which is a short name indicating the
+            str: The username of the Digilent Waveforms device, which is a short name indicating the
             device type (e.g., "Discovery2", "DDiscovery").
 
         Raises:
-            DwfLibraryError: The user name of the Digilent Waveforms device cannot be retrieved.
+            DwfLibraryError: The username of the Digilent Waveforms device cannot be retrieved.
         """
         c_username = ctypes.create_string_buffer(32)
         result = self.lib.FDwfEnumUserName(device_index, c_username)
