@@ -1,6 +1,5 @@
 """The |pydwf.core.api.digital_can| module implements a single class: |DigitalCan|."""
 
-from typing import Tuple
 import ctypes
 
 from pydwf.core.dwf_device_subapi import AbstractDwfDeviceSubApi
@@ -60,7 +59,7 @@ class DigitalCan(AbstractDwfDeviceSubApi):
         """Set the digital channel (pin) where the outgoing (TX) signal will be transmitted.
 
         Parameters:
-            channel_index (int): The channel (digital pin number) on which to transmit data.
+            channel_index (int): The digital channel (pin) on which to transmit data.
 
         Raises:
             DwfLibraryError: An error occurred while executing the operation.
@@ -73,7 +72,7 @@ class DigitalCan(AbstractDwfDeviceSubApi):
         """Set the digital channel (pin) where the incoming (RX) signal is received.
 
         Parameters:
-            channel_index (int): The channel (digital pin number) on which to receive data.
+            channel_index (int): The digital channel (pin) on which to receive data.
 
         Raises:
             DwfLibraryError: An error occurred while executing the operation.
@@ -116,17 +115,17 @@ class DigitalCan(AbstractDwfDeviceSubApi):
         if result != RESULT_SUCCESS:
             raise self.dwf.exception()
 
-    def rx(self, size: int = 8) -> Tuple[int, bool, bool, bytes, int]:
+    def rx(self, size: int = 8) -> tuple[int, bool, bool, bytes, int]:
         """Receive incoming CAN bus data.
 
         Returns:
-            Tuple[int, bool, bool, bytes, int]: A tuple (vID, extended, remote, data, status)
+            tuple[int, bool, bool, bytes, int]: A tuple (vID, extended, remote, data, status)
 
         Raises:
             DwfLibraryError: An error occurred while executing the operation.
         """
 
-        c_vID      = typespec_ctypes.c_int()
+        c_v_id     = typespec_ctypes.c_int()
         c_extended = typespec_ctypes.c_int()
         c_remote   = typespec_ctypes.c_int()
         c_dlc      = typespec_ctypes.c_int()
@@ -135,7 +134,7 @@ class DigitalCan(AbstractDwfDeviceSubApi):
 
         result = self.lib.FDwfDigitalCanRx(
             self.hdwf,
-            c_vID,
+            c_v_id,
             c_extended,
             c_remote,
             c_dlc,
@@ -145,11 +144,11 @@ class DigitalCan(AbstractDwfDeviceSubApi):
         if result != RESULT_SUCCESS:
             raise self.dwf.exception()
 
-        vID      = c_vID.value
+        v_id      = c_v_id.value
         extended = bool(c_extended.value)
         remote   = bool(c_remote.value)
         dlc      = c_dlc.value
         data     = c_data.value[:dlc]
         status   = c_status.value
 
-        return (vID, extended, remote, data, status)
+        return (v_id, extended, remote, data, status)
