@@ -1,7 +1,5 @@
 """The |pydwf.core.api.DigitalI2c| module implements a single class: |DigitalI2c|."""
 
-from typing import List, Tuple
-
 from pydwf.core.dwf_device_subapi import AbstractDwfDeviceSubApi
 
 from pydwf.core.auxiliary.typespec_ctypes import typespec_ctypes
@@ -114,7 +112,7 @@ class DigitalI2c(AbstractDwfDeviceSubApi):
         """Set the digital channel (pin) where the I²C clock (SCL) signal is transmitted.
 
         Parameters:
-            channel_index (int): The channel (digital pin number) on which to generate the SCL clock.
+            channel_index (int): The digital channel (pin) on which to generate the SCL clock.
 
         Raises:
             DwfLibraryError: An error occurred while executing the operation.
@@ -127,7 +125,7 @@ class DigitalI2c(AbstractDwfDeviceSubApi):
         """Set the digital channel (pin) where the I²C data (SDA) signal is transmitted/received.
 
         Parameters:
-            channel_index (int): The channel (digital pin number) on which to send/receive SDA data.
+            channel_index (int): The digital channel (pin) on which to send/receive SDA data.
 
         Raises:
             DwfLibraryError: An error occurred while executing the operation.
@@ -136,16 +134,16 @@ class DigitalI2c(AbstractDwfDeviceSubApi):
         if result != RESULT_SUCCESS:
             raise self.dwf.exception()
 
-    def writeRead(self, address: int, tx: List[int], number_of_rx_bytes: int) -> Tuple[int, List[int]]:
+    def writeRead(self, address: int, tx: list[int], number_of_rx_bytes: int) -> tuple[int, list[int]]:
         """Perform a combined I²C write/read operation.
 
         Parameters:
             address (int): The I²C address of the target device.
-            tx (List[int]): The octets to send.
+            tx (list[int]): The octets to send.
             number_of_rx_bytes (int): The number of octets to receive.
 
         Returns:
-            Tuple[int, List[int]:
+            tuple[int, list[int]]:
                 The first element is the NAK indication; the second element is a list of octet values received.
 
         Raises:
@@ -180,7 +178,7 @@ class DigitalI2c(AbstractDwfDeviceSubApi):
 
         return (nak, rx_list)
 
-    def read(self, address: int, number_of_words: int) -> Tuple[int, List[int]]:
+    def read(self, address: int, number_of_words: int) -> tuple[int, list[int]]:
         """Perform an I²C read operation.
 
         Parameters:
@@ -211,7 +209,7 @@ class DigitalI2c(AbstractDwfDeviceSubApi):
 
         return (nak, rx_list)
 
-    def write(self, address: int, tx: List[int]) -> int:
+    def write(self, address: int, tx: list[int]) -> int:
         """Perform an I²C write operation.
 
         Parameters:
@@ -276,9 +274,12 @@ class DigitalI2c(AbstractDwfDeviceSubApi):
         if result != RESULT_SUCCESS:
             raise self.dwf.exception()
 
-    def spyStatus(self, max_data_size: int) -> Tuple[int, int, List[int], int]:
+    def spyStatus(self, max_data_size: int) -> tuple[int, int, list[int], int]:
         """Get I²C spy status.
 
+        Returns:
+            tuple[int, int, list[int], int]: A tuple (start, stop, data-values, nak-indicator).
+
         Raises:
             DwfLibraryError: An error occurred while executing the operation.
         """
