@@ -2,8 +2,6 @@
 
 # pylint: disable=too-many-lines
 
-from typing import List, Tuple
-
 import numpy as np
 
 from pydwf.core.dwf_device_subapi import AbstractDwfDeviceSubApi
@@ -36,7 +34,7 @@ class DigitalIn(AbstractDwfDeviceSubApi):
     def reset(self) -> None:
         """Reset the |DigitalIn| instrument parameters to default values.
 
-        If auto-configure is enabled, the reset values will be used immediately.
+        If autoconfiguration is enabled, the reset values will be used immediately.
 
         Raises:
             DwfLibraryError: An error occurred while executing the *reset* operation.
@@ -103,11 +101,11 @@ class DigitalIn(AbstractDwfDeviceSubApi):
     #                                                                                                                  #
     ####################################################################################################################
 
-    def statusTime(self) -> Tuple[int, int, int]:
+    def statusTime(self) -> tuple[int, int, int]:
         """Get the timestamp of the current status information.
 
         Returns:
-            Tuple[int, int, int]: A three-element tuple, indicating the POSIX timestamp of the status request.
+            tuple[int, int, int]: A three-element tuple, indicating the POSIX timestamp of the status request.
             The first element is the POSIX second, the second and third element are the numerator and denominator,
             respectively, of the fractional part of the second.
 
@@ -158,12 +156,12 @@ class DigitalIn(AbstractDwfDeviceSubApi):
         Raises:
             DwfLibraryError: An error occurred while executing the operation.
         """
-        c_samplesLeft = typespec_ctypes.c_int()
-        result = self.lib.FDwfDigitalInStatusSamplesLeft(self.hdwf, c_samplesLeft)
+        c_samples_left = typespec_ctypes.c_int()
+        result = self.lib.FDwfDigitalInStatusSamplesLeft(self.hdwf, c_samples_left)
         if result != RESULT_SUCCESS:
             raise self.dwf.exception()
-        samplesLeft = c_samplesLeft.value
-        return samplesLeft
+        samples_left = c_samples_left.value
+        return samples_left
 
     def statusSamplesValid(self) -> int:
         """Retrieve the number of valid data samples.
@@ -200,11 +198,11 @@ class DigitalIn(AbstractDwfDeviceSubApi):
         index_write = c_index_write.value
         return index_write
 
-    def statusRecord(self) -> Tuple[int, int, int]:
+    def statusRecord(self) -> tuple[int, int, int]:
         """Get the recording status.
 
         Returns:
-            Tuple[int, int, int]: A three-element tuple containing the counts for
+            tuple[int, int, int]: A three-element tuple containing the counts for
             *available*, *lost*, and *corrupt* data samples, in that order.
 
         Raises:
@@ -302,18 +300,18 @@ class DigitalIn(AbstractDwfDeviceSubApi):
         Raises:
             DwfLibraryError: An error occurred while executing the operation.
         """
-        c_hzFreq = typespec_ctypes.c_double()
-        result = self.lib.FDwfDigitalInInternalClockInfo(self.hdwf, c_hzFreq)
+        c_frequency = typespec_ctypes.c_double()
+        result = self.lib.FDwfDigitalInInternalClockInfo(self.hdwf, c_frequency)
         if result != RESULT_SUCCESS:
             raise self.dwf.exception()
-        hzFreq = c_hzFreq.value
-        return hzFreq
+        frequency = c_frequency.value
+        return frequency
 
-    def clockSourceInfo(self) -> List[DwfDigitalInClockSource]:
+    def clockSourceInfo(self) -> list[DwfDigitalInClockSource]:
         """Get a list of valid clock sources for the |DigitalIn| instrument.
 
         Returns:
-            List[DwfDigitalInClockSource]: A list of valid clock sources.
+            list[DwfDigitalInClockSource]: A list of valid clock sources.
 
         Raises:
             DwfLibraryError: An error occurred while executing the operation.
@@ -410,11 +408,11 @@ class DigitalIn(AbstractDwfDeviceSubApi):
     #                                                                                                                  #
     ####################################################################################################################
 
-    def acquisitionModeInfo(self) -> List[DwfAcquisitionMode]:
+    def acquisitionModeInfo(self) -> list[DwfAcquisitionMode]:
         """Get a list of valid |DigitalIn| instrument acquisition modes.
 
         Returns:
-            List[DwfAcquisitionMode]: A list of valid acquisition modes for the |DigitalIn| instrument.
+            list[DwfAcquisitionMode]: A list of valid acquisition modes for the |DigitalIn| instrument.
 
         Raises:
             DwfLibraryError: An error occurred while executing the operation.
@@ -566,11 +564,11 @@ class DigitalIn(AbstractDwfDeviceSubApi):
         buffer_size = c_buffer_size.value
         return buffer_size
 
-    def sampleModeInfo(self) -> List[DwfDigitalInSampleMode]:
+    def sampleModeInfo(self) -> list[DwfDigitalInSampleMode]:
         """Get the valid |DigitalIn| instrument sample modes.
 
         Returns:
-            List[DwfDigitalInSampleMode]: A list of valid sample modes.
+            list[DwfDigitalInSampleMode]: A list of valid sample modes.
 
         Raises:
             DwfLibraryError: An error occurred while executing the operation.
@@ -696,7 +694,7 @@ class DigitalIn(AbstractDwfDeviceSubApi):
     #                                                                                                                  #
     ####################################################################################################################
 
-    def triggerSourceInfo(self) -> List[DwfTriggerSource]:
+    def triggerSourceInfo(self) -> list[DwfTriggerSource]:
         """Get the valid |DigitalIn| instrument trigger sources.
 
         Warning:
@@ -705,7 +703,7 @@ class DigitalIn(AbstractDwfDeviceSubApi):
             Use the generic :py:meth:`DeviceControl.triggerInfo()` method instead.
 
         Returns:
-            List[DwfTriggerSource]: A list of valid trigger sources.
+            list[DwfTriggerSource]: A list of valid trigger sources.
 
         Raises:
             DwfLibraryError: An error occurred while executing the operation.
@@ -824,11 +822,11 @@ class DigitalIn(AbstractDwfDeviceSubApi):
         samples_after_trigger = c_samples_after_trigger.value
         return samples_after_trigger
 
-    def triggerAutoTimeoutInfo(self) -> Tuple[float, float, int]:
+    def triggerAutoTimeoutInfo(self) -> tuple[float, float, int]:
         """Get |DigitalIn| instrument trigger auto-timeout range, in seconds.
 
         Returns:
-            Tuple[float, float, int]: The range and number of steps of the auto-timeout setting.
+            tuple[float, float, int]: The range and number of steps of the auto-timeout setting.
 
         Raises:
             DwfLibraryError: An error occurred while executing the operation.
@@ -845,7 +843,7 @@ class DigitalIn(AbstractDwfDeviceSubApi):
             raise self.dwf.exception()
 
         if not c_trigger_auto_timeout_num_steps.value.is_integer():
-            raise PyDwfError("Bad c_trigger_autotimout_num_steps value.")
+            raise PyDwfError("Bad c_trigger_auto_timeout_num_steps value.")
 
         trigger_auto_timeout_min = c_trigger_auto_timeout_min.value
         trigger_auto_timeout_max = c_trigger_auto_timeout_max.value
@@ -887,14 +885,14 @@ class DigitalIn(AbstractDwfDeviceSubApi):
     #                                                                                                                  #
     ####################################################################################################################
 
-    def triggerInfo(self) -> Tuple[int, int, int, int]:
+    def triggerInfo(self) -> tuple[int, int, int, int]:
         """Get |DigitalIn| detector trigger info.
 
-        Return the pins that support the different types of triggering. Each integer is a bitmask, representing pins\
-            that can be used as *low level*, *high level*, *rising edge*, and *falling edge* triggers.
+        Return the pins that support the different types of triggering. Each integer is a bitmask, representing pins
+        that can be used as *low level*, *high level*, *rising edge*, and *falling edge* triggers.
 
         Returns:
-            Tuple[int, int, int, int]: Digital pins that can be used as *low level*, *high level*, *rising edge*,
+            tuple[int, int, int, int]: Digital pins that can be used as *low level*, *high level*, *rising edge*,
             and *falling edge* triggers, respectively.
 
         Raises:
@@ -946,11 +944,11 @@ class DigitalIn(AbstractDwfDeviceSubApi):
         if result != RESULT_SUCCESS:
             raise self.dwf.exception()
 
-    def triggerGet(self) -> Tuple[int, int, int, int]:
+    def triggerGet(self) -> tuple[int, int, int, int]:
         """Get the configured |DigitalIn| trigger detector settings.
 
         Returns:
-            Tuple[int, int, int, int]: The currently configured *level_low*, *level_high*, *edge_rise*,
+            tuple[int, int, int, int]: The currently configured *level_low*, *level_high*, *edge_rise*,
             and *edge_fall* settings.
 
         Raises:
@@ -1028,7 +1026,7 @@ class DigitalIn(AbstractDwfDeviceSubApi):
                   specifies the timing length.
 
                   Used for UART, CAN protocols.
-                * 2 — PWM: the *min_length* parameter specifies sthe ampling time and the *max_length* parameter
+                * 2 — PWM: the *min_length* parameter specifies the sampling time and the *max_length* parameter
                   specifies the timing length.
 
                   Used for 1-wire protocols.
