@@ -25,7 +25,7 @@ class DigitalIO(AbstractDwfDeviceSubApi):
 
         It sets the digital pins to tri-state (high impedance, not enabled) and output value to zero.
 
-        If auto-configure is enabled, the values are immediately applied.
+        If autoconfiguration is enabled, the values are immediately applied.
 
         Raises:
             DwfLibraryError: An error occurred while executing the *reset* operation.
@@ -38,7 +38,7 @@ class DigitalIO(AbstractDwfDeviceSubApi):
         """Configure the |DigitalIO| functionality.
 
         This method transfers the settings to the Digilent Waveforms device. It is not needed
-        if auto-configure is enabled.
+        if autoconfiguration is enabled.
 
         Raises:
             DwfLibraryError: An error occurred while executing the *configure* operation.
