@@ -1,7 +1,6 @@
 """The |pydwf.core.api.digital_out| module implements a single class: |DigitalOut|."""
 
 import ctypes
-from typing import Tuple, List
 
 from pydwf.core.dwf_device_subapi import AbstractDwfDeviceSubApi
 
@@ -100,11 +99,11 @@ class DigitalOut(AbstractDwfDeviceSubApi):
     #                                                                                                                  #
     ####################################################################################################################
 
-    def waitInfo(self) -> Tuple[float, float]:
+    def waitInfo(self) -> tuple[float, float]:
         """Get the |DigitalOut| instrument range for the |Wait:link| state duration, in seconds.
 
         Returns:
-            Tuple[float, float]: A tuple containing the minimal and maximal configurable |Wait:link| state duration,
+            tuple[float, float]: A tuple containing the minimal and maximal configurable |Wait:link| state duration,
             in seconds.
 
         Raises:
@@ -148,11 +147,11 @@ class DigitalOut(AbstractDwfDeviceSubApi):
         wait_duration = c_wait_duration.value
         return wait_duration
 
-    def runInfo(self) -> Tuple[float, float]:
+    def runInfo(self) -> tuple[float, float]:
         """Get the |DigitalOut| instrument range for the |Running:link| state duration, in seconds.
 
         Returns:
-            Tuple[float, float]: A tuple containing the minimal and maximal |Running:link| state duration, in seconds.
+            tuple[float, float]: A tuple containing the minimal and maximal |Running:link| state duration, in seconds.
 
         Raises:
             DwfLibraryError: An error occurred while executing the operation.
@@ -253,11 +252,11 @@ class DigitalOut(AbstractDwfDeviceSubApi):
         repeat_trigger_flag = bool(c_repeat_trigger.value)
         return repeat_trigger_flag
 
-    def repeatInfo(self) -> Tuple[int, int]:
+    def repeatInfo(self) -> tuple[int, int]:
         """Get the |DigitalOut| minimal and maximal repeat count for pulse-sequence runs.
 
         Returns:
-            Tuple[int, int]: A tuple containing the minimal and maximal repeat count for
+            tuple[int, int]: A tuple containing the minimal and maximal repeat count for
             digital-out pulse-sequence runs.
 
         Raises:
@@ -327,7 +326,7 @@ class DigitalOut(AbstractDwfDeviceSubApi):
     #                                                                                                                  #
     ####################################################################################################################
 
-    def triggerSourceInfo(self) -> List[DwfTriggerSource]:
+    def triggerSourceInfo(self) -> list[DwfTriggerSource]:
         """Get the valid |DigitalOut| trigger sources.
 
         Warning:
@@ -336,7 +335,7 @@ class DigitalOut(AbstractDwfDeviceSubApi):
             Use the generic DeviceControl.triggerInfo() method instead.
 
         Returns:
-            List[DwfTriggerSource]: A list of valid the trigger sources.
+            list[DwfTriggerSource]: A list of valid the trigger sources.
 
         Raises:
             DwfLibraryError: An error occurred while executing the operation.
@@ -447,11 +446,11 @@ class DigitalOut(AbstractDwfDeviceSubApi):
         enable_flag = bool(c_enable_flag.value)
         return enable_flag
 
-    def outputInfo(self, channel_index: int) -> List[DwfDigitalOutOutput]:
+    def outputInfo(self, channel_index: int) -> list[DwfDigitalOutOutput]:
         """Get valid |DigitalOut| output choices (e.g. Push/Pull, tristate).
 
         Returns:
-            List[DwfDigitalOutOutput]: A list of valid output settings.
+            list[DwfDigitalOutOutput]: A list of valid output settings.
 
         Raises:
             DwfLibraryError: An error occurred while executing the operation.
@@ -497,7 +496,7 @@ class DigitalOut(AbstractDwfDeviceSubApi):
         output_value = DwfDigitalOutOutput(c_output_value.value)
         return output_value
 
-    def typeInfo(self, channel_index: int) -> List[DwfDigitalOutType]:
+    def typeInfo(self, channel_index: int) -> list[DwfDigitalOutType]:
         """Get a list of valid |DigitalOut| output channel types.
 
         Returns:
@@ -547,11 +546,11 @@ class DigitalOut(AbstractDwfDeviceSubApi):
         output_type = DwfDigitalOutType(c_output_type.value)
         return output_type
 
-    def idleInfo(self, channel_index: int) -> List[DwfDigitalOutIdle]:
+    def idleInfo(self, channel_index: int) -> list[DwfDigitalOutIdle]:
         """Get valid |DigitalOut| idle output values.
 
         Returns:
-            List[DwfDigitalOutIdle]: A list of valid idle output values.
+            list[DwfDigitalOutIdle]: A list of valid idle output values.
 
         Raises:
             DwfLibraryError: An error occurred while executing the operation.
@@ -619,11 +618,11 @@ class DigitalOut(AbstractDwfDeviceSubApi):
         internal_clock_frequency = c_internal_clock_frequency.value
         return internal_clock_frequency
 
-    def dividerInfo(self, channel_index: int) -> Tuple[int, int]:
+    def dividerInfo(self, channel_index: int) -> tuple[int, int]:
         """Get the |DigitalOut| divider value range.
 
         Returns:
-            Tuple[int, int]: The range of valid divider settings.
+            tuple[int, int]: The range of valid divider settings.
 
         Raises:
             DwfLibraryError: An error occurred while executing the operation.
@@ -707,14 +706,14 @@ class DigitalOut(AbstractDwfDeviceSubApi):
         divider_init = c_divider_init.value
         return divider_init
 
-    def counterInfo(self, channel_index: int) -> Tuple[int, int]:
+    def counterInfo(self, channel_index: int) -> tuple[int, int]:
         """Get the |DigitalOut| counter value range.
 
         Parameters:
             channel_index (int): The digital pin.
 
         Returns:
-            Tuple[int, int]: The range of valid counter settings.
+            tuple[int, int]: The range of valid counter settings.
 
         Raises:
             DwfLibraryError: An error occurred while executing the operation.
@@ -747,14 +746,14 @@ class DigitalOut(AbstractDwfDeviceSubApi):
         if result != RESULT_SUCCESS:
             raise self.dwf.exception()
 
-    def counterGet(self, channel_index: int) -> Tuple[int, int]:
+    def counterGet(self, channel_index: int) -> tuple[int, int]:
         """Get the |DigitalOut| counter durations for both the low and high signal output levels.
 
         Parameters:
             channel_index (int): The digital pin.
 
         Returns:
-            Tuple[int, int]: The number of cycles the signal should be Low, High.
+            tuple[int, int]: The number of cycles the signal should be Low, High.
 
         Raises:
             DwfLibraryError: An error occurred while executing the operation.
@@ -786,14 +785,14 @@ class DigitalOut(AbstractDwfDeviceSubApi):
         if result != RESULT_SUCCESS:
             raise self.dwf.exception()
 
-    def counterInitGet(self, channel_index: int) -> Tuple[bool, int]:
+    def counterInitGet(self, channel_index: int) -> tuple[bool, int]:
         """Get the |DigitalOut| initial signal value and initial counter value.
 
         Parameters:
             channel_index (int): The digital pin.
 
         Returns:
-            Tuple [bool, int]: Whether to start High (True) or Low (False),
+            tuple [bool, int]: Whether to start High (True) or Low (False),
             and the initial counter setting.
 
         Raises:
@@ -876,7 +875,7 @@ class DigitalOut(AbstractDwfDeviceSubApi):
     def playDataSet(self, bits: str, bits_per_sample: int, count_of_samples: int) -> None:
         """Set the |DigitalOut| playback data.
 
-        The output can be PushPull, OpenDrain, or OpenSource. Threestate data is not supported.
+        The output can be PushPull, OpenDrain, or OpenSource. Tristate data is not supported.
 
         Note:
             The DWF documentation explicitly states that this function is supported by the Digital Discovery.
