@@ -1,7 +1,5 @@
 """The |pydwf.core.api.digital_spi| module implements a single class: |DigitalSpi|."""
 
-from typing import List
-
 from pydwf.core.dwf_device_subapi import AbstractDwfDeviceSubApi
 
 from pydwf.core.auxiliary.typespec_ctypes import typespec_ctypes
@@ -159,12 +157,12 @@ class DigitalSpi(AbstractDwfDeviceSubApi):
                 *  1 — high
                 * -1 — Z (high impedance)
 
-                The CS (chip select) is usually an active-low signal, from the
-                SPI bus master to a specific SPI slave device. Before starting a bus
-                request, the master should set CS to 0 for the chip it wants to talk to.
+                The CS (chip select) is an active-low signal, from the SPI bus master to a
+                specific SPI slave device. Before starting a bus request, the master should
+                set CS to 0 for the chip it wants to talk to.
 
-                Usually, each slave on an SPI bus has its own CS line. At most one of them
-                should be selected at any time.
+                Each slave on an SPI bus has its own CS line. At most one of them should be
+                selected at any time.
 
         Raises:
             DwfLibraryError: An error occurred while executing the operation.
@@ -173,7 +171,7 @@ class DigitalSpi(AbstractDwfDeviceSubApi):
         if result != RESULT_SUCCESS:
             raise self.dwf.exception()
 
-    def writeRead(self, transfer_type: int, bits_per_word: int, tx: List[int]) -> List[int]:
+    def writeRead(self, transfer_type: int, bits_per_word: int, tx: list[int]) -> list[int]:
         """Write and read multiple SPI data-words, with up to 8 bits per data-word.
 
         Parameters:
@@ -184,11 +182,11 @@ class DigitalSpi(AbstractDwfDeviceSubApi):
                 * 4 — quad
             bits_per_word (int):
                 The number of bits per data-word (1…8).
-            tx (List[int]):
+            tx (list[int]):
                 The data-words to write.
 
         Returns:
-            List[int]: The data-words received.
+            list[int]: The data-words received.
 
         Raises:
             DwfLibraryError: An error occurred while executing the write/read operation.
@@ -217,7 +215,7 @@ class DigitalSpi(AbstractDwfDeviceSubApi):
 
         return rx_list
 
-    def writeRead16(self, transfer_type: int, bits_per_word: int, tx: List[int]) -> List[int]:
+    def writeRead16(self, transfer_type: int, bits_per_word: int, tx: list[int]) -> list[int]:
         """Write and read multiple SPI data-words, with up to 16 bits per data-word.
 
         Parameters:
@@ -228,11 +226,11 @@ class DigitalSpi(AbstractDwfDeviceSubApi):
                 * 4 — quad
             bits_per_word (int):
                 The number of bits per data-word (1…16).
-            tx (List[int]):
+            tx (list[int]):
                 The data-words to write.
 
         Returns:
-            List[int]: The data-words received.
+            list[int]: The data-words received.
 
         Raises:
             DwfLibraryError: An error occurred while executing the write/read operation.
@@ -261,7 +259,7 @@ class DigitalSpi(AbstractDwfDeviceSubApi):
 
         return rx_list
 
-    def writeRead32(self, transfer_type: int, bits_per_word: int, tx: List[int]) -> List[int]:
+    def writeRead32(self, transfer_type: int, bits_per_word: int, tx: list[int]) -> list[int]:
         """Write and read multiple SPI data-words, with up to 32 bits per data-word.
 
         Parameters:
@@ -272,11 +270,11 @@ class DigitalSpi(AbstractDwfDeviceSubApi):
                 * 4 — quad
             bits_per_word (int):
                 The number of bits per data-word (1…32).
-            tx (List[int]):
+            tx (list[int]):
                 The data-words to write.
 
         Returns:
-            List[int]: The data-words received.
+            list[int]: The data-words received.
 
         Raises:
             DwfLibraryError: An error occurred while executing the write/read operation.
@@ -306,7 +304,7 @@ class DigitalSpi(AbstractDwfDeviceSubApi):
 
         return rx_list
 
-    def read(self, transfer_type: int, bits_per_word: int, number_of_words: int) -> List[int]:
+    def read(self, transfer_type: int, bits_per_word: int, number_of_words: int) -> list[int]:
         """Read multiple SPI data-words, with up to 8 bits per data-word.
 
         Parameters:
@@ -321,7 +319,7 @@ class DigitalSpi(AbstractDwfDeviceSubApi):
                 The number of data-words to read.
 
         Returns:
-            List[int]: The data-words received.
+            list[int]: The data-words received.
 
         Raises:
             DwfLibraryError: An error occurred while executing the read operation.
@@ -344,7 +342,7 @@ class DigitalSpi(AbstractDwfDeviceSubApi):
 
         return rx_list
 
-    def read16(self, transfer_type: int, bits_per_word: int, number_of_words: int) -> List[int]:
+    def read16(self, transfer_type: int, bits_per_word: int, number_of_words: int) -> list[int]:
         """Read multiple SPI data-words, with up to 16 bits per data-word.
 
         Parameters:
@@ -359,7 +357,7 @@ class DigitalSpi(AbstractDwfDeviceSubApi):
                 The number of data-words to read.
 
         Returns:
-            List[int]: The data-words received.
+            list[int]: The data-words received.
 
         Raises:
             DwfLibraryError: An error occurred while executing the read operation.
@@ -382,7 +380,7 @@ class DigitalSpi(AbstractDwfDeviceSubApi):
 
         return rx_list
 
-    def read32(self, transfer_type: int, bits_per_word: int, number_of_words: int) -> List[int]:
+    def read32(self, transfer_type: int, bits_per_word: int, number_of_words: int) -> list[int]:
         """Read multiple SPI data-words, with up to 32 bits per data-word.
 
         Parameters:
@@ -397,7 +395,7 @@ class DigitalSpi(AbstractDwfDeviceSubApi):
                 The number of data-words to read.
 
         Returns:
-            List[int]: The data-words received.
+            list[int]: The data-words received.
 
         Raises:
             DwfLibraryError: An error occurred while executing the read operation.
@@ -445,7 +443,7 @@ class DigitalSpi(AbstractDwfDeviceSubApi):
         rx = c_rx.value
         return rx
 
-    def write(self, transfer_type: int, bits_per_word: int, tx: List[int]) -> None:
+    def write(self, transfer_type: int, bits_per_word: int, tx: list[int]) -> None:
         """Write multiple SPI data-words, with up to 32 bits per data-word.
 
         Parameters:
@@ -456,7 +454,7 @@ class DigitalSpi(AbstractDwfDeviceSubApi):
                 * 4 — quad
             bits_per_word (int):
                 The number of bits per data-word (1…32).
-            tx (List[int]):
+            tx (list[int]):
                 The data-words to write.
 
         Raises:
@@ -479,7 +477,7 @@ class DigitalSpi(AbstractDwfDeviceSubApi):
         if result != RESULT_SUCCESS:
             raise self.dwf.exception()
 
-    def write16(self, transfer_type: int, bits_per_word: int, tx: List[int]) -> None:
+    def write16(self, transfer_type: int, bits_per_word: int, tx: list[int]) -> None:
         """Write multiple SPI data-words, with up to 16 bits per data-word.
 
         Parameters:
@@ -490,7 +488,7 @@ class DigitalSpi(AbstractDwfDeviceSubApi):
                 * 4 — quad
             bits_per_word (int):
                 The number of bits per data-word (1…16).
-            tx (List[int]):
+            tx (list[int]):
                 The data-words to write.
 
         Raises:
@@ -513,7 +511,7 @@ class DigitalSpi(AbstractDwfDeviceSubApi):
         if result != RESULT_SUCCESS:
             raise self.dwf.exception()
 
-    def write32(self, transfer_type: int, bits_per_word: int, tx: List[int]) -> None:
+    def write32(self, transfer_type: int, bits_per_word: int, tx: list[int]) -> None:
         """Write multiple SPI data-words, with up to 32 bits per data-word.
 
         Parameters:
@@ -524,7 +522,7 @@ class DigitalSpi(AbstractDwfDeviceSubApi):
                 * 4 — quad
             bits_per_word (int):
                 The number of bits per data-word (1…32).
-            tx (List[int]):
+            tx (list[int]):
                 The data-words to write.
 
         Raises:
