@@ -1,7 +1,6 @@
 """The |pydwf.core.api.digital_uart| module implements a single class: |DigitalUart|."""
 
 import ctypes
-from typing import Tuple
 
 from pydwf.core.dwf_device_subapi import AbstractDwfDeviceSubApi
 
@@ -83,7 +82,7 @@ class DigitalUart(AbstractDwfDeviceSubApi):
         """Set the UART signal polarity.
 
         Parameters:
-            parity (int): The polarity used by the receiver and transmitter:
+            polarity (int): The polarity used by the receiver and transmitter:
 
                 * 0 — normal
                 * 1 — inverted
@@ -158,7 +157,7 @@ class DigitalUart(AbstractDwfDeviceSubApi):
         if result != RESULT_SUCCESS:
             raise self.dwf.exception()
 
-    def rx(self, rx_max: int) -> Tuple[bytes, int]:
+    def rx(self, rx_max: int) -> tuple[bytes, int]:
         """Receive UART data or prepare for reception.
 
         Important:
@@ -170,7 +169,7 @@ class DigitalUart(AbstractDwfDeviceSubApi):
                 Otherwise, receive the specified number of characters.
 
         Returns:
-            Tuple[bytes, int]: Bytes received and parity error indication.
+            tuple[bytes, int]: Bytes received and parity error indication.
 
         Todo:
             The meaning of the parity error indication is currently unclear.
