@@ -1,5 +1,7 @@
 """The |pydwf.core.dwf_device_subapi| module implements a single class: |AbstractDwfDeviceSubApi|."""
 
+from __future__ import annotations
+
 from typing import TYPE_CHECKING
 
 if TYPE_CHECKING:
@@ -9,7 +11,7 @@ if TYPE_CHECKING:
 class AbstractDwfDeviceSubApi:
     """Abstract base class for the sub-API attributes of a |DwfDevice|."""
 
-    def __init__(self, device: 'DwfDevice'):
+    def __init__(self, device: DwfDevice):
         self._device = device
 
     @property
